#!/bin/sh

rpm -q nss-tools || exit 1

PATH=/usr/sbin:$PATH

which perftest 2>/dev/null && alias qpid-perftest="perftest"

# clean up
./clean.sh

# prepare server

echo -n Generating certificates...
{
    echo "hoj11597" > pwdfile.txt
    echo "aoeunthao eanote haont he432 aontueh" > noise.txt
    certutil -N -d . -f pwdfile.txt
    certutil -G -d . -z noise.txt -f pwdfile.txt
    certutil -S -n ourCA -s "cn=CAcert" -x -t "CT,," -m 1000 -v 120 -d . \
        -z noise.txt -f pwdfile.txt
    certutil -S -n ourServer -s "CN=$HOSTNAME,O=acme,ST=Mass,C=US" \
        -c ourCA -t "u,u,u" -m 1001 -v 120 -d . -z noise.txt -f pwdfile.txt
} >>test.log 2>&1 && echo ok

# run server

echo -n Running broker...
{
qpidd -d --ssl-cert-db $PWD --data-dir $PWD/qpidd \
      --ssl-cert-password-file $PWD/pwdfile.txt \
      --ssl-cert-name ourServer \
      --auth yes --require-encryption \
      --log-to-file qpidd.log -t
} >>test.log 2>&1 && echo ok

# prepare env of the client
export QPID_LOAD_MODULE=`rpm -ql qpidc-ssl qpid-cpp-client-ssl 2>/dev/null | grep sslconnector.so`
export QPID_SSL_CERT_DB=$PWD

# run client

echo -n Running client...
{
qpid-perftest -p 5671 -P ssl -b $HOSTNAME \
         --count 1 --mechanism PLAIN \
         --username guest --password guest
} >>test.log 2>&1 && echo ok || echo FAILURE

echo -n Stopping broker...
{
	qpidd --data-dir $PWD/qpidd -q
} >>test.log 2>&1 && echo ok
